## This script generates the boxplots needed for Figure 5

## Import data
card = read.csv("combined_both_years_data_all_columns_for_pub.csv")
## Subset dataset where only points that detected males are included
work = card[card$PointWork==1,]

## Examine detections-only (work) dataset for response aggression (PC1.BOTH) and preplayback aggression (PRE.PC1.BOTH)
## To modify this script to generate boxplots for the full dataset, replace "work" with "card" below. 
## To modify this script to generate boxplots for other principal components (PC2, PC3, PC4, or PC5), replace PC1 with the PC of your choice. 
## Note this will not work for PC1.BOTH.
names(work) 
plot(work$PC1.BOTH~work$Type)
plot(work$PRE.PC1.BOTH~work$Type)

## Perform a One Way Anova
## This tests whether there are significant differences between aggression
## based on the Type heard (REL.TO.BARRIER = Local, Distant, Across, Control)
## and the population being tested (Portal birds PT or Big Bend birds BB)
fit = aov(PC1.BOTH ~ REL.TO.BARRIER+TESTED.POP+REL.TO.BARRIER:TESTED.POP, data=work) 
summary(fit) 
'#                           Df Sum Sq Mean Sq F value  Pr(>F)    
#REL.TO.BARRIER              3  212.9   70.96  30.814 < 2e-16 ***
#TESTED.POP                  1    1.5    1.45   0.630   0.428    
#REL.TO.BARRIER:TESTED.POP   3   58.1   19.35   8.404 2.1e-05 ***
#Residuals                 340  783.0    2.30                    
#---
#Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1'

## Perform anotehr one way Anova testing whether these same factors
## Significantly influence pre-playback aggression
fit2 = aov(PRE.PC1.BOTH ~ REL.TO.BARRIER+TESTED.POP+REL.TO.BARRIER:TESTED.POP, data=work)
summary(fit2) ## tested pop is significant! sig difs in pre-pb aggression between the two 
'#                           Df Sum Sq Mean Sq F value Pr(>F)  
#REL.TO.BARRIER              3   1.45  0.4829   1.178 0.3181  
#TESTED.POP                  1   2.11  2.1125   5.153 0.0238 *
#REL.TO.BARRIER:TESTED.POP   3   0.17  0.0559   0.136 0.9382  
#Residuals                 340 139.38  0.4099                 
#---
#Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1'

## get the overall range of response aggression
summary(work$PC1.BOTH)

## perform t-tests between song types with respect to population tested
## note not all permutations were tested, this was don

## subset datasets by desert, by PCA analysis, and by location relative to barrier
local.son = work$PC1.SON[work$REL.TO.BARRIER=="LOCAL"]
local.chi = work$PC1.CHI[work$REL.TO.BARRIER=="LOCAL"]
local.both = work$PC1.BOTH[work$REL.TO.BARRIER=="LOCAL"]
control.son = work$PC1.SON[work$REL.TO.BARRIER=="NULL"]
control.chi = work$PC1.CHI[work$REL.TO.BARRIER=="NULL"]
control.both = work$PC1.BOTH[work$REL.TO.BARRIER=="NULL"]
across.son = work$PC1.SON[work$REL.TO.BARRIER=="ACROSS-BARRIER"]
across.chi = work$PC1.CHI[work$REL.TO.BARRIER=="ACROSS-BARRIER"]
across.both = work$PC1.BOTH[work$REL.TO.BARRIER=="ACROSS-BARRIER"]
distant.son = work$PC1.SON[work$REL.TO.BARRIER=="DISTANT"]
distant.chi = work$PC1.CHI[work$REL.TO.BARRIER=="DISTANT"]
distant.both = work$PC1.BOTH[work$REL.TO.BARRIER=="DISTANT"]

## FIGURE 5 
## Figure 5 is made from two boxplots each plotted here. 
## Those are then added to the other imagery in an image editing program.
## Note that the Chihuahuan desert PC1 is negatively correlated with aggression, so its y-axis is reversed.

## Boxplots are colored by significance, i.e., boxes of the same color are statistically indistinguishable
library(RColorBrewer)
color = brewer.pal(12, "Paired")
red = color[6]; blue = color[1]
png("Figure5_1_sonoran_boxplot_relative.png",
    width=6,height=2,pointsize=10,units="in",res=300)
par(mar=c(2,4,1,1))
boxplot(distant.son,local.son,across.son,control.son,names=c("Distant","Local","Across-Barrier","Control"),main="Sonoran",
        ylim=c(min(local.son,distant.son,across.son,control.son,na.rm=T),max(local.son,distant.son,across.son,control.son,na.rm=T)),
        col=c(blue,red,blue,blue),ylab="Aggression (PC1)",
        boxwex=0.5)

dev.off()
png("Figure1_2_chihuahuan_boxplot_relative.png",
    width=6,height=2,pointsize=10,units="in",res=300)
par(mar=c(2,4,1,1))
boxplot(control.chi,across.chi,local.chi,distant.chi,names=c("Control","Across-Barrier","Local","Distant"),main="Chihuahuan",
        ylim=c(max(local.chi,distant.chi,across.chi,control.chi,na.rm=T),min(local.chi,distant.chi,across.chi,control.chi,na.rm=T)),
        col=c(blue,blue,red,red),ylab="Aggression (PC1)",
        boxwex=0.5)
dev.off()



