## This script generates Figure 6.

## Import data and subset to take only those that worked
card <- read.csv("combined_both_years_data_all_columns_for_pub.csv")
card_sec_as_num = card[card$PointWork==1,]

## Look at column titles and extract the start and end of the distance-by-second section.
names(card_sec_as_num)
start_col = which(names(card_sec_as_num)=="Sec010")
end_col = which(names(card_sec_as_num)=="Sec540")

## standard error function
sterr <- function(x) sd(x)/sqrt(length(x))

## calculate means and standard errors of distances for each treatment, both deserts
mean.matrix = as.data.frame(matrix(0,ncol=54,nrow=4))
sterr.matrix = as.data.frame(matrix(0,ncol=54,nrow=4))
for (i in start_col:end_col) {
  #print(i)
  x = c(mean(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="NULL",(i)]),
        mean(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="ACROSS-BARRIER",(i)]),
        mean(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="DISTANT",(i)]),
        mean(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="LOCAL",(i)]))  
  mean.matrix[,i-31] = as.numeric(x)
  #print(c(i,x))
  colnames(mean.matrix)=colnames(card_sec_as_num[start_col:end_col])
  
  z = c(sterr(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="NULL",(i)]),
        sterr(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="ACROSS-BARRIER",(i)]),
        sterr(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="DISTANT",(i)]),
        sterr(card_sec_as_num[card_sec_as_num$REL.TO.BARRIER=="LOCAL",(i)]))  
  sterr.matrix[,i-31] = as.numeric(z)
  #print(c(i,z))
  colnames(sterr.matrix)=colnames(card_sec_as_num[start_col:end_col])
  
}

## add a column describing which treatment is which
mean.matrix = cbind(Test = c("NULL","ACROSS-BARRIER","DISTANT","LOCAL"),mean.matrix)
sterr.matrix = cbind(Test = c("NULL","ACROSS-BARRIER","DISTANT","LOCAL"),sterr.matrix)

## extract the means and standard deviations for each treatment
con.mean = as.numeric(mean.matrix[mean.matrix$Test=="NULL",-1]) ## gives values for NULL
acr.mean = as.numeric(mean.matrix[mean.matrix$Test=="ACROSS-BARRIER",-1]) ## gives values for ACROSS-BARRIER
dis.mean = as.numeric(mean.matrix[mean.matrix$Test=="DISTANT",-1]) ## gives values for DISTANT
loc.mean = as.numeric(mean.matrix[mean.matrix$Test=="LOCAL",-1]) ## gives values for LOCAL

con.sterr = as.numeric((sterr.matrix[sterr.matrix$Test=="NULL",-1])) ## gives values for control
acr.sterr = as.numeric((sterr.matrix[sterr.matrix$Test=="ACROSS-BARRIER",-1])) ## gives values for across barrier
dis.sterr = as.numeric((sterr.matrix[sterr.matrix$Test=="DISTANT",-1])) ## gives values for distant
loc.sterr = as.numeric((sterr.matrix[sterr.matrix$Test=="LOCAL",-1])) ## gives values for local


## generate the plot
library(RColorBrewer)

col = brewer.pal(12,"Paired")
lightblue=col[1]
blue=col[2]
lightgreen=col[3]
green=col[4]
violet=col[9]
purple=col[10]

seconds = seq(10,540,10)
epsilon=0.02

### PLOT with tubes not points

acr.high = acr.mean+acr.sterr
acr.low = acr.mean-acr.sterr
con.high=con.mean+con.sterr
con.low=con.mean-con.sterr
dis.high=dis.mean+dis.sterr
dis.low=dis.mean-dis.sterr
loc.high=loc.mean+loc.sterr
loc.low=loc.mean-loc.sterr

pdf(file="FIGURE 6 - mean_dist_by_time_bothyears_TUBES.pdf",
    width=5,height=4,pointsize=10)
par(mar=c(4,4,0,0))
plot(seconds,acr.mean,col=blue,pch=22,bg=lightblue,type="l",lty=2,
     xlab="Time (s)",ylab="Distance from speaker (m)",
     #main="Mean (SE) Dist from Speaker vs Time",
     xaxp  = c(0, 540, 9),
     ylim=c(14,24))
abline(v=180,col="gray")
abline(v=360,col="gray")
polygon(c(seconds, rev(seconds)), c(acr.high, rev(acr.low)),
        col = adjustcolor(lightblue,alpha.f=0.5), border = NA)
polygon(c(seconds, rev(seconds)), c(dis.high, rev(dis.low)),
        col = adjustcolor(lightgreen,alpha.f=0.5), border = NA)
polygon(c(seconds, rev(seconds)), c(con.high, rev(con.low)),
        col = adjustcolor("grey",alpha.f=0.5), border = NA)
polygon(c(seconds, rev(seconds)), c(loc.high, rev(loc.low)),
        col = adjustcolor(violet,alpha.f=0.5), border = NA)
lines(seconds,acr.mean,col=blue,pch=22,bg=lightblue,ylim=c(14,24),lty=2)
lines(seconds,dis.mean,col=green,pch=22,bg=lightgreen,ylim=c(14,24),lty=5)
lines(seconds,con.mean,col="black",pch=22,bg="grey",ylim=c(14,24),lty=3)
lines(seconds,loc.mean,col=purple,pch=22,bg=violet,ylim=c(14,24),lty=1)
legend(10,16.5,c("Local","Distant","Across-Barrier","Control"),
       col=c(purple,green,blue,"black"),lwd=1,
       lty=c(1,5,2,3),
       fill = c(adjustcolor(violet,alpha.f=0.5),
                adjustcolor(lightgreen,alpha.f=0.5),
                adjustcolor(lightblue,alpha.f=0.5),
                adjustcolor("grey",alpha.f=0.5)),
       border=c(purple,green,blue,"black"))
dev.off()

